# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/policies/v1/policies_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/policies/v1/policies_v1.proto\x12\x1bstrmprivacy.api.policies.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\x15\n\x13ListPoliciesRequest\"W\n\x14ListPoliciesResponse\x12?\n\x08policies\x18\x01 \x03(\x0b\x32#.strmprivacy.api.entities.v1.PolicyR\x08policies\"7\n\x13\x44\x65letePolicyRequest\x12 \n\tpolicy_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x08policyId\"\x16\n\x14\x44\x65letePolicyResponse\"R\n\x13\x43reatePolicyRequest\x12;\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyR\x06policy\"S\n\x14\x43reatePolicyResponse\x12;\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyR\x06policy\"\x94\x01\n\x13UpdatePolicyRequest\x12;\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyR\x06policy\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"S\n\x14UpdatePolicyResponse\x12;\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyR\x06policy\"4\n\x10GetPolicyRequest\x12 \n\tpolicy_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x08policyId\"P\n\x11GetPolicyResponse\x12;\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyR\x06policy2\xd1\x04\n\x0fPoliciesService\x12s\n\x0cListPolicies\x12\x30.strmprivacy.api.policies.v1.ListPoliciesRequest\x1a\x31.strmprivacy.api.policies.v1.ListPoliciesResponse\x12j\n\tGetPolicy\x12-.strmprivacy.api.policies.v1.GetPolicyRequest\x1a..strmprivacy.api.policies.v1.GetPolicyResponse\x12s\n\x0c\x44\x65letePolicy\x12\x30.strmprivacy.api.policies.v1.DeletePolicyRequest\x1a\x31.strmprivacy.api.policies.v1.DeletePolicyResponse\x12s\n\x0c\x43reatePolicy\x12\x30.strmprivacy.api.policies.v1.CreatePolicyRequest\x1a\x31.strmprivacy.api.policies.v1.CreatePolicyResponse\x12s\n\x0cUpdatePolicy\x12\x30.strmprivacy.api.policies.v1.UpdatePolicyRequest\x1a\x31.strmprivacy.api.policies.v1.UpdatePolicyResponseBi\n\x1eio.strmprivacy.api.policies.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v2/api/policies/v1;policiesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.policies.v1.policies_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.policies.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v2/api/policies/v1;policies'
  _DELETEPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _DELETEPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\340A\002'
  _UPDATEPOLICYREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _GETPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _GETPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\340A\002'
  _LISTPOLICIESREQUEST._serialized_start=192
  _LISTPOLICIESREQUEST._serialized_end=213
  _LISTPOLICIESRESPONSE._serialized_start=215
  _LISTPOLICIESRESPONSE._serialized_end=302
  _DELETEPOLICYREQUEST._serialized_start=304
  _DELETEPOLICYREQUEST._serialized_end=359
  _DELETEPOLICYRESPONSE._serialized_start=361
  _DELETEPOLICYRESPONSE._serialized_end=383
  _CREATEPOLICYREQUEST._serialized_start=385
  _CREATEPOLICYREQUEST._serialized_end=467
  _CREATEPOLICYRESPONSE._serialized_start=469
  _CREATEPOLICYRESPONSE._serialized_end=552
  _UPDATEPOLICYREQUEST._serialized_start=555
  _UPDATEPOLICYREQUEST._serialized_end=703
  _UPDATEPOLICYRESPONSE._serialized_start=705
  _UPDATEPOLICYRESPONSE._serialized_end=788
  _GETPOLICYREQUEST._serialized_start=790
  _GETPOLICYREQUEST._serialized_end=842
  _GETPOLICYRESPONSE._serialized_start=844
  _GETPOLICYRESPONSE._serialized_end=924
  _POLICIESSERVICE._serialized_start=927
  _POLICIESSERVICE._serialized_end=1520
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/metrics/v1/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(strmprivacy/api/metrics/v1/metrics.proto\x12\x1astrmprivacy.api.metrics.v1\x1a\x1fgoogle/api/field_behavior.proto\"\x17\n\x15GetSystemStateRequest\"k\n\x16GetSystemStateResponse\x12Q\n\roverall_state\x18\x01 \x01(\x0e\x32\'.strmprivacy.api.metrics.v1.SystemStateB\x03\xe0\x41\x03R\x0coverallState*S\n\x0bSystemState\x12\x1c\n\x18SYSTEM_STATE_UNSPECIFIED\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x0e\n\nMAJOR_DOWN\x10\x02\x12\x0e\n\nMINOR_DOWN\x10\x03\x32\x89\x01\n\x0eMetricsService\x12w\n\x0eGetSystemState\x12\x31.strmprivacy.api.metrics.v1.GetSystemStateRequest\x1a\x32.strmprivacy.api.metrics.v1.GetSystemStateResponseBf\n\x1dio.strmprivacy.api.metrics.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/metrics/v1;metricsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.metrics.v1.metrics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.metrics.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/metrics/v1;metrics'
  _GETSYSTEMSTATERESPONSE.fields_by_name['overall_state']._options = None
  _GETSYSTEMSTATERESPONSE.fields_by_name['overall_state']._serialized_options = b'\340A\003'
  _SYSTEMSTATE._serialized_start=239
  _SYSTEMSTATE._serialized_end=322
  _GETSYSTEMSTATEREQUEST._serialized_start=105
  _GETSYSTEMSTATEREQUEST._serialized_end=128
  _GETSYSTEMSTATERESPONSE._serialized_start=130
  _GETSYSTEMSTATERESPONSE._serialized_end=237
  _METRICSSERVICE._serialized_start=325
  _METRICSSERVICE._serialized_end=462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/consent_levels/v1/consent_levels_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/consent_levels/v1/consent_levels_v1.proto\x12!strmprivacy.api.consent_levels.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"h\n\x1fListConsentLevelMappingsRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x8a\x01\n ListConsentLevelMappingsResponse\x12\x66\n\x16\x63onsent_level_mappings\x18\x01 \x03(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMappingR\x14\x63onsentLevelMappings\"n\n DeleteConsentLevelMappingRequest\x12J\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02R\x03ref\"#\n!DeleteConsentLevelMappingResponse\"\x88\x01\n CreateConsentLevelMappingRequest\x12\x64\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMappingR\x13\x63onsentLevelMapping\"\x89\x01\n!CreateConsentLevelMappingResponse\x12\x64\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMappingR\x13\x63onsentLevelMapping\"k\n\x1dGetConsentLevelMappingRequest\x12J\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02R\x03ref\"\x86\x01\n\x1eGetConsentLevelMappingResponse\x12\x64\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMappingR\x13\x63onsentLevelMapping2\xb5\x05\n\x1b\x43onsentLevelMappingsService\x12\xa3\x01\n\x18ListConsentLevelMappings\x12\x42.strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsRequest\x1a\x43.strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsResponse\x12\x9d\x01\n\x16GetConsentLevelMapping\x12@.strmprivacy.api.consent_levels.v1.GetConsentLevelMappingRequest\x1a\x41.strmprivacy.api.consent_levels.v1.GetConsentLevelMappingResponse\x12\xa6\x01\n\x19\x44\x65leteConsentLevelMapping\x12\x43.strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingRequest\x1a\x44.strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingResponse\x12\xa6\x01\n\x19\x43reateConsentLevelMapping\x12\x43.strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingRequest\x1a\x44.strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingResponseB{\n$io.strmprivacy.api.consent_levels.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/consent_levels/v1;consent_levelsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.consent_levels.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/consent_levels/v1;consent_levels'
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['billing_id']._options = None
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['project_id']._options = None
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETECONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._options = None
  _DELETECONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETCONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._options = None
  _GETCONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTCONSENTLEVELMAPPINGSREQUEST._serialized_start=176
  _LISTCONSENTLEVELMAPPINGSREQUEST._serialized_end=280
  _LISTCONSENTLEVELMAPPINGSRESPONSE._serialized_start=283
  _LISTCONSENTLEVELMAPPINGSRESPONSE._serialized_end=421
  _DELETECONSENTLEVELMAPPINGREQUEST._serialized_start=423
  _DELETECONSENTLEVELMAPPINGREQUEST._serialized_end=533
  _DELETECONSENTLEVELMAPPINGRESPONSE._serialized_start=535
  _DELETECONSENTLEVELMAPPINGRESPONSE._serialized_end=570
  _CREATECONSENTLEVELMAPPINGREQUEST._serialized_start=573
  _CREATECONSENTLEVELMAPPINGREQUEST._serialized_end=709
  _CREATECONSENTLEVELMAPPINGRESPONSE._serialized_start=712
  _CREATECONSENTLEVELMAPPINGRESPONSE._serialized_end=849
  _GETCONSENTLEVELMAPPINGREQUEST._serialized_start=851
  _GETCONSENTLEVELMAPPINGREQUEST._serialized_end=958
  _GETCONSENTLEVELMAPPINGRESPONSE._serialized_start=961
  _GETCONSENTLEVELMAPPINGRESPONSE._serialized_end=1095
  _CONSENTLEVELMAPPINGSSERVICE._serialized_start=1098
  _CONSENTLEVELMAPPINGSSERVICE._serialized_end=1791
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_subjects/v1/data_subjects_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/data_subjects/v1/data_subjects_v1.proto\x12 strmprivacy.api.data_subjects.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/descriptor.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"q\n\x1eListDataSubjectKeylinksRequest\x12&\n\x0f\x64\x61ta_subject_id\x18\x01 \x03(\tR\rdataSubjectId\x12\'\n\x0forganization_id\x18\x02 \x01(\tR\x0eorganizationId\"\x8c\x01\n\x1fListDataSubjectKeylinksResponse\x12i\n\x15\x64\x61ta_subject_keylinks\x18\x01 \x03(\x0b\x32\x35.strmprivacy.api.data_subjects.v1.DatasubjectKeylinksR\x13\x64\x61taSubjectKeylinks\"\xaf\x01\n\x1e\x41\x64\x64\x44\x61taSubjectsKeyLinksRequest\x12\"\n\nproject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12i\n\x15\x64\x61ta_subject_keylinks\x18\x02 \x03(\x0b\x32\x35.strmprivacy.api.data_subjects.v1.DatasubjectKeylinksR\x13\x64\x61taSubjectKeylinks\"\xd3\x02\n\x1f\x41\x64\x64\x44\x61taSubjectsKeyLinksResponse\x12!\n\x0cstored_count\x18\x01 \x01(\x03R\x0bstoredCount\x12s\n\x06issues\x18\x02 \x03(\x0b\x32W.strmprivacy.api.data_subjects.v1.AddDataSubjectsKeyLinksResponse.AddDataSubjectsIssuesB\x02\x18\x01R\x06issues\x1a\x97\x01\n\x15\x41\x64\x64\x44\x61taSubjectsIssues\x12&\n\x0f\x64\x61ta_subject_id\x18\x01 \x01(\tR\rdataSubjectId\x12\x19\n\x08key_link\x18\x02 \x01(\tR\x07keyLink\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\x1d\n\nissue_type\x18\x04 \x01(\tR\tissueType:\x02\x18\x01\"\xb5\x02\n\x13\x44\x61tasubjectKeylinks\x12+\n\x0f\x64\x61ta_subject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\rdataSubjectId\x12\x81\x01\n\x17keylinks_and_timestamps\x18\x02 \x03(\x0b\x32I.strmprivacy.api.data_subjects.v1.DatasubjectKeylinks.KeylinkAndTimestampR\x15keylinksAndTimestamps\x1am\n\x13KeylinkAndTimestamp\x12\x19\n\x08key_link\x18\x01 \x01(\tR\x07keyLink\x12;\n\x0b\x65xpiry_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nexpiryTime\"i\n\x19\x44\x65leteDataSubjectsRequest\x12#\n\rdata_subjects\x18\x01 \x03(\tR\x0c\x64\x61taSubjects\x12\'\n\x0forganization_id\x18\x02 \x01(\tR\x0eorganizationId\"R\n\x1a\x44\x65leteDataSubjectsResponse\x12\x34\n\x16\x64\x65leted_keylinks_count\x18\x01 \x01(\x03R\x14\x64\x65letedKeylinksCount\"~\n\x17ListDataSubjectsRequest\x12\x1d\n\npage_token\x18\x01 \x01(\tR\tpageToken\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\'\n\x0forganization_id\x18\x03 \x01(\tR\x0eorganizationId\"\xee\x01\n\x18ListDataSubjectsResponse\x12o\n\rdata_subjects\x18\x01 \x03(\x0b\x32J.strmprivacy.api.data_subjects.v1.ListDataSubjectsResponse.DataSubjectInfoR\x0c\x64\x61taSubjects\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x1a\x39\n\x0f\x44\x61taSubjectInfo\x12&\n\x0f\x64\x61ta_subject_id\x18\x01 \x01(\tR\rdataSubjectId2\xf5\x04\n\x13\x44\x61taSubjectsService\x12\x9e\x01\n\x17ListDataSubjectKeylinks\x12@.strmprivacy.api.data_subjects.v1.ListDataSubjectKeylinksRequest\x1a\x41.strmprivacy.api.data_subjects.v1.ListDataSubjectKeylinksResponse\x12\x9e\x01\n\x17\x41\x64\x64\x44\x61taSubjectsKeyLinks\x12@.strmprivacy.api.data_subjects.v1.AddDataSubjectsKeyLinksRequest\x1a\x41.strmprivacy.api.data_subjects.v1.AddDataSubjectsKeyLinksResponse\x12\x8f\x01\n\x12\x44\x65leteDataSubjects\x12;.strmprivacy.api.data_subjects.v1.DeleteDataSubjectsRequest\x1a<.strmprivacy.api.data_subjects.v1.DeleteDataSubjectsResponse\x12\x89\x01\n\x10ListDataSubjects\x12\x39.strmprivacy.api.data_subjects.v1.ListDataSubjectsRequest\x1a:.strmprivacy.api.data_subjects.v1.ListDataSubjectsResponseBx\n#io.strmprivacy.api.data_subjects.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/data_subjects/v1;data_subjectsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.data_subjects.v1.data_subjects_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.data_subjects.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/data_subjects/v1;data_subjects'
  _ADDDATASUBJECTSKEYLINKSREQUEST.fields_by_name['project_id']._options = None
  _ADDDATASUBJECTSKEYLINKSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._options = None
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._serialized_options = b'\030\001'
  _ADDDATASUBJECTSKEYLINKSRESPONSE.fields_by_name['issues']._options = None
  _ADDDATASUBJECTSKEYLINKSRESPONSE.fields_by_name['issues']._serialized_options = b'\030\001'
  _DATASUBJECTKEYLINKS.fields_by_name['data_subject_id']._options = None
  _DATASUBJECTKEYLINKS.fields_by_name['data_subject_id']._serialized_options = b'\340A\002'
  _LISTDATASUBJECTKEYLINKSREQUEST._serialized_start=193
  _LISTDATASUBJECTKEYLINKSREQUEST._serialized_end=306
  _LISTDATASUBJECTKEYLINKSRESPONSE._serialized_start=309
  _LISTDATASUBJECTKEYLINKSRESPONSE._serialized_end=449
  _ADDDATASUBJECTSKEYLINKSREQUEST._serialized_start=452
  _ADDDATASUBJECTSKEYLINKSREQUEST._serialized_end=627
  _ADDDATASUBJECTSKEYLINKSRESPONSE._serialized_start=630
  _ADDDATASUBJECTSKEYLINKSRESPONSE._serialized_end=969
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._serialized_start=818
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._serialized_end=969
  _DATASUBJECTKEYLINKS._serialized_start=972
  _DATASUBJECTKEYLINKS._serialized_end=1281
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP._serialized_start=1172
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP._serialized_end=1281
  _DELETEDATASUBJECTSREQUEST._serialized_start=1283
  _DELETEDATASUBJECTSREQUEST._serialized_end=1388
  _DELETEDATASUBJECTSRESPONSE._serialized_start=1390
  _DELETEDATASUBJECTSRESPONSE._serialized_end=1472
  _LISTDATASUBJECTSREQUEST._serialized_start=1474
  _LISTDATASUBJECTSREQUEST._serialized_end=1600
  _LISTDATASUBJECTSRESPONSE._serialized_start=1603
  _LISTDATASUBJECTSRESPONSE._serialized_end=1841
  _LISTDATASUBJECTSRESPONSE_DATASUBJECTINFO._serialized_start=1784
  _LISTDATASUBJECTSRESPONSE_DATASUBJECTINFO._serialized_end=1841
  _DATASUBJECTSSERVICE._serialized_start=1844
  _DATASUBJECTSSERVICE._serialized_end=2473
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/entities_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2strmprivacy/api/installations/v1/entities_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xad\x02\n\x0cInstallation\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12\x64\n\x11installation_type\x18\x02 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\x12,\n\x12\x62illing_account_id\x18\x03 \x01(\tR\x10\x62illingAccountId\x12t\n\x18installation_credentials\x18\x04 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstallationCredentialsR\x17installationCredentials\"\x96\x01\n\x17InstallationCredentials\x12 \n\tclient_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x08\x63lientId\x12(\n\rclient_secret\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0c\x63lientSecret\x12/\n\x11image_pull_secret\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0fimagePullSecret\"\xd6\x01\n\x12InstalledComponent\x12\x64\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02R\rcomponentType\x12Z\n\tinstances\x18\x02 \x03(\x0b\x32<.strmprivacy.api.installations.v1.InstalledComponentInstanceR\tinstances\"\x84\x01\n\x1aInstalledComponentInstance\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12Q\n\x06states\x18\x02 \x03(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateR\x06states\"\xef\x01\n\x1fInstalledComponentsCurrentState\x12\x64\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02R\rcomponentType\x12\x66\n\tinstances\x18\x02 \x03(\x0b\x32H.strmprivacy.api.installations.v1.InstalledComponentInstanceCurrentStateR\tinstances\"\x8e\x01\n&InstalledComponentInstanceCurrentState\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12O\n\x05state\x18\x02 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateR\x05state\"\xdb\x01\n\x17InstalledComponentState\x12>\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstateTime\x12\x61\n\nstate_type\x18\x02 \x01(\x0e\x32=.strmprivacy.api.installations.v1.InstalledComponentStateTypeB\x03\xe0\x41\x02R\tstateType\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x07message*\x7f\n\x10InstallationType\x12!\n\x1dINSTALLATION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAAS\x10\x01\x12\x0f\n\x0bSELF_HOSTED\x10\x02\x12\x13\n\x0f\x41WS_MARKETPLACE\x10\x03\x12\x18\n\x14\x41WS_MARKETPLACE_PAYG\x10\x04*\xfb\x01\n\x16InstalledComponentType\x12(\n$INSTALLED_COMPONENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42\x41TCH_JOBS_AGENT\x10\x01\x12\x19\n\x15\x42\x41TCH_EXPORTERS_AGENT\x10\x02\x12\x19\n\x15KAFKA_EXPORTERS_AGENT\x10\x03\x12\x11\n\rSTREAMS_AGENT\x10\x04\x12\x11\n\rEVENT_GATEWAY\x10\x05\x12\x0e\n\nWEB_SOCKET\x10\x06\x12\x19\n\x15\x44\x41TA_CONNECTORS_AGENT\x10\x07\x12\x1a\n\x16\x43ONFLUENT_SCHEMA_PROXY\x10\x08*\x89\x01\n\x1bInstalledComponentStateType\x12.\n*INSTALLED_COMPONENT_STATE_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bPROVISIONED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x11\n\rSHUTTING_DOWN\x10\x04\x42x\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.installations.v1.entities_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _INSTALLATION.fields_by_name['id']._options = None
  _INSTALLATION.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLATION.fields_by_name['installation_type']._options = None
  _INSTALLATION.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._serialized_options = b'\340A\001'
  _INSTALLATIONTYPE._serialized_start=1572
  _INSTALLATIONTYPE._serialized_end=1699
  _INSTALLEDCOMPONENTTYPE._serialized_start=1702
  _INSTALLEDCOMPONENTTYPE._serialized_end=1953
  _INSTALLEDCOMPONENTSTATETYPE._serialized_start=1956
  _INSTALLEDCOMPONENTSTATETYPE._serialized_end=2093
  _INSTALLATION._serialized_start=155
  _INSTALLATION._serialized_end=456
  _INSTALLATIONCREDENTIALS._serialized_start=459
  _INSTALLATIONCREDENTIALS._serialized_end=609
  _INSTALLEDCOMPONENT._serialized_start=612
  _INSTALLEDCOMPONENT._serialized_end=826
  _INSTALLEDCOMPONENTINSTANCE._serialized_start=829
  _INSTALLEDCOMPONENTINSTANCE._serialized_end=961
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_start=964
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_end=1203
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_start=1206
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_end=1348
  _INSTALLEDCOMPONENTSTATE._serialized_start=1351
  _INSTALLEDCOMPONENTSTATE._serialized_end=1570
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/installed_components_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>strmprivacy/api/installations/v1/installed_components_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\"\xdc\x02\n$UpdateInstalledComponentStateRequest\x12\x64\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02R\rcomponentType\x12$\n\x0binstance_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\ninstanceId\x12z\n\x19installed_component_state\x18\x03 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateB\x03\xe0\x41\x02R\x17installedComponentState\x12,\n\x0finstallation_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId\"\'\n%UpdateInstalledComponentStateResponse\"\xc5\x01\n\x1cGetInstalledComponentRequest\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId\x12w\n\x18installed_component_type\x18\x02 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02R\x16installedComponentType\"\x86\x01\n\x1dGetInstalledComponentResponse\x12\x65\n\x13installed_component\x18\x01 \x01(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponentR\x12installedComponent\"N\n\x1eListInstalledComponentsRequest\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId\"\x8a\x01\n\x1fListInstalledComponentsResponse\x12g\n\x14installed_components\x18\x01 \x03(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponentR\x13installedComponents\"[\n+ListInstalledComponentsCurrentStatesRequest\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId\"\xa4\x01\n,ListInstalledComponentsCurrentStatesResponse\x12t\n\x14installed_components\x18\x01 \x03(\x0b\x32\x41.strmprivacy.api.installations.v1.InstalledComponentsCurrentStateR\x13installedComponents2\xd3\x05\n\x1aInstalledComponentsService\x12\xb0\x01\n\x1dUpdateInstalledComponentState\x12\x46.strmprivacy.api.installations.v1.UpdateInstalledComponentStateRequest\x1aG.strmprivacy.api.installations.v1.UpdateInstalledComponentStateResponse\x12\x98\x01\n\x15GetInstalledComponent\x12>.strmprivacy.api.installations.v1.GetInstalledComponentRequest\x1a?.strmprivacy.api.installations.v1.GetInstalledComponentResponse\x12\x9e\x01\n\x17ListInstalledComponents\x12@.strmprivacy.api.installations.v1.ListInstalledComponentsRequest\x1a\x41.strmprivacy.api.installations.v1.ListInstalledComponentsResponse\x12\xc5\x01\n$ListInstalledComponentsCurrentStates\x12M.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesRequest\x1aN.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesResponseBx\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.installations.v1.installed_components_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._serialized_options = b'\340A\002'
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_start=186
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_end=534
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_start=536
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_end=575
  _GETINSTALLEDCOMPONENTREQUEST._serialized_start=578
  _GETINSTALLEDCOMPONENTREQUEST._serialized_end=775
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_start=778
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_end=912
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_start=914
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_end=992
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_start=995
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_end=1133
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_start=1135
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_end=1226
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_start=1229
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_end=1393
  _INSTALLEDCOMPONENTSSERVICE._serialized_start=1396
  _INSTALLEDCOMPONENTSSERVICE._serialized_end=2119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/batch_exporters/v1/batch_exporters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/batch_exporters/v1/batch_exporters_v1.proto\x12\"strmprivacy.api.batch_exporters.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"b\n\x19ListBatchExportersRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"q\n\x1aListBatchExportersResponse\x12S\n\x0f\x62\x61tch_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\x0e\x62\x61tchExporters\"b\n\x1a\x44\x65leteBatchExporterRequest\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02R\x03ref\"\x1d\n\x1b\x44\x65leteBatchExporterResponse\"o\n\x1a\x43reateBatchExporterRequest\x12Q\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\rbatchExporter\"p\n\x1b\x43reateBatchExporterResponse\x12Q\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\rbatchExporter\"_\n\x17GetBatchExporterRequest\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02R\x03ref\"m\n\x18GetBatchExporterResponse\x12Q\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\rbatchExporter2\xef\x04\n\x15\x42\x61tchExportersService\x12\x93\x01\n\x12ListBatchExporters\x12=.strmprivacy.api.batch_exporters.v1.ListBatchExportersRequest\x1a>.strmprivacy.api.batch_exporters.v1.ListBatchExportersResponse\x12\x8d\x01\n\x10GetBatchExporter\x12;.strmprivacy.api.batch_exporters.v1.GetBatchExporterRequest\x1a<.strmprivacy.api.batch_exporters.v1.GetBatchExporterResponse\x12\x96\x01\n\x13\x44\x65leteBatchExporter\x12>.strmprivacy.api.batch_exporters.v1.DeleteBatchExporterRequest\x1a?.strmprivacy.api.batch_exporters.v1.DeleteBatchExporterResponse\x12\x96\x01\n\x13\x43reateBatchExporter\x12>.strmprivacy.api.batch_exporters.v1.CreateBatchExporterRequest\x1a?.strmprivacy.api.batch_exporters.v1.CreateBatchExporterResponseB~\n%io.strmprivacy.api.batch_exporters.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/batch_exporters/v1;batch_exportersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.batch_exporters.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/batch_exporters/v1;batch_exporters'
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEBATCHEXPORTERREQUEST.fields_by_name['ref']._options = None
  _DELETEBATCHEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERREQUEST.fields_by_name['ref']._options = None
  _GETBATCHEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTBATCHEXPORTERSREQUEST._serialized_start=179
  _LISTBATCHEXPORTERSREQUEST._serialized_end=277
  _LISTBATCHEXPORTERSRESPONSE._serialized_start=279
  _LISTBATCHEXPORTERSRESPONSE._serialized_end=392
  _DELETEBATCHEXPORTERREQUEST._serialized_start=394
  _DELETEBATCHEXPORTERREQUEST._serialized_end=492
  _DELETEBATCHEXPORTERRESPONSE._serialized_start=494
  _DELETEBATCHEXPORTERRESPONSE._serialized_end=523
  _CREATEBATCHEXPORTERREQUEST._serialized_start=525
  _CREATEBATCHEXPORTERREQUEST._serialized_end=636
  _CREATEBATCHEXPORTERRESPONSE._serialized_start=638
  _CREATEBATCHEXPORTERRESPONSE._serialized_end=750
  _GETBATCHEXPORTERREQUEST._serialized_start=752
  _GETBATCHEXPORTERREQUEST._serialized_end=847
  _GETBATCHEXPORTERRESPONSE._serialized_start=849
  _GETBATCHEXPORTERRESPONSE._serialized_end=958
  _BATCHEXPORTERSSERVICE._serialized_start=961
  _BATCHEXPORTERSSERVICE._serialized_end=1584
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/organizations/v1/organizations_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/organizations/v1/organizations_v1.proto\x12 strmprivacy.api.organizations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\x93\x01\n\x12InviteUsersRequest\x12T\n\x0cuser_invites\x18\x01 \x03(\x0b\x32,.strmprivacy.api.organizations.v1.UserInviteB\x03\xe0\x41\x02R\x0buserInvites\x12\'\n\x0forganization_id\x18\x02 \x01(\tR\x0eorganizationId\"\'\n\nUserInvite\x12\x19\n\x05\x65mail\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05\x65mail\"\x8a\x02\n\x13InviteUsersResponse\x12!\n\x0cinvite_count\x18\x01 \x01(\x03R\x0binviteCount\x12]\n\x06issues\x18\x02 \x03(\x0b\x32\x45.strmprivacy.api.organizations.v1.InviteUsersResponse.UserInviteIssueR\x06issues\x1aq\n\x0fUserInviteIssue\x12\x44\n\x06invite\x18\x01 \x01(\x0b\x32,.strmprivacy.api.organizations.v1.UserInviteR\x06invite\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"v\n\x16UpdateUserRolesRequest\x12\x16\n\x06\x65mails\x18\x01 \x03(\tR\x06\x65mails\x12\x44\n\nuser_roles\x18\x02 \x03(\x0e\x32%.strmprivacy.api.entities.v1.UserRoleR\tuserRoles\"\x19\n\x17UpdateUserRolesResponse\" \n\x1eListOrganizationMembersRequest\"w\n\x1fListOrganizationMembersResponse\x12T\n\x14organization_members\x18\x01 \x03(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x13organizationMembers\"&\n\x0eGetUserRequest\x12\x14\n\x05\x65mail\x18\x01 \x01(\tR\x05\x65mail\"H\n\x0fGetUserResponse\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x04user2\xac\x04\n\x14OrganizationsService\x12z\n\x0bInviteUsers\x12\x34.strmprivacy.api.organizations.v1.InviteUsersRequest\x1a\x35.strmprivacy.api.organizations.v1.InviteUsersResponse\x12\x86\x01\n\x0fUpdateUserRoles\x12\x38.strmprivacy.api.organizations.v1.UpdateUserRolesRequest\x1a\x39.strmprivacy.api.organizations.v1.UpdateUserRolesResponse\x12n\n\x07GetUser\x12\x30.strmprivacy.api.organizations.v1.GetUserRequest\x1a\x31.strmprivacy.api.organizations.v1.GetUserResponse\x12\x9e\x01\n\x17ListOrganizationMembers\x12@.strmprivacy.api.organizations.v1.ListOrganizationMembersRequest\x1a\x41.strmprivacy.api.organizations.v1.ListOrganizationMembersResponseBx\n#io.strmprivacy.api.organizations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/organizations/v1;organizationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.organizations.v1.organizations_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.organizations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/organizations/v1;organizations'
  _INVITEUSERSREQUEST.fields_by_name['user_invites']._options = None
  _INVITEUSERSREQUEST.fields_by_name['user_invites']._serialized_options = b'\340A\002'
  _USERINVITE.fields_by_name['email']._options = None
  _USERINVITE.fields_by_name['email']._serialized_options = b'\340A\002'
  _INVITEUSERSREQUEST._serialized_start=174
  _INVITEUSERSREQUEST._serialized_end=321
  _USERINVITE._serialized_start=323
  _USERINVITE._serialized_end=362
  _INVITEUSERSRESPONSE._serialized_start=365
  _INVITEUSERSRESPONSE._serialized_end=631
  _INVITEUSERSRESPONSE_USERINVITEISSUE._serialized_start=518
  _INVITEUSERSRESPONSE_USERINVITEISSUE._serialized_end=631
  _UPDATEUSERROLESREQUEST._serialized_start=633
  _UPDATEUSERROLESREQUEST._serialized_end=751
  _UPDATEUSERROLESRESPONSE._serialized_start=753
  _UPDATEUSERROLESRESPONSE._serialized_end=778
  _LISTORGANIZATIONMEMBERSREQUEST._serialized_start=780
  _LISTORGANIZATIONMEMBERSREQUEST._serialized_end=812
  _LISTORGANIZATIONMEMBERSRESPONSE._serialized_start=814
  _LISTORGANIZATIONMEMBERSRESPONSE._serialized_end=933
  _GETUSERREQUEST._serialized_start=935
  _GETUSERREQUEST._serialized_end=973
  _GETUSERRESPONSE._serialized_start=975
  _GETUSERRESPONSE._serialized_end=1047
  _ORGANIZATIONSSERVICE._serialized_start=1050
  _ORGANIZATIONSSERVICE._serialized_end=1606
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/usage/v1/usage_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/usage/v1/usage_v1.proto\x12\x18strmprivacy.api.usage.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xff\x01\n\x1aGetStreamEventUsageRequest\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefR\x03ref\x12\x39\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x35\n\x08interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08interval\"\xa2\x01\n\x1bGetStreamEventUsageResponse\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefR\x03ref\x12I\n\x07windows\x18\x02 \x03(\x0b\x32/.strmprivacy.api.entities.v1.WindowedEventCountR\x07windows\"\xdd\x01\n\x16StoreUsageEventRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x16\n\x06stream\x18\x02 \x01(\tR\x06stream\x12\x1f\n\x0b\x65vent_count\x18\x03 \x01(\x05R\neventCount\x12H\n\x12\x65vent_arrival_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x65ventArrivalTime\x12\x1d\n\nproject_id\x18\x05 \x01(\tR\tprojectId\"\x19\n\x17StoreUsageEventResponse2\x8b\x02\n\x0cUsageService\x12\x82\x01\n\x13GetStreamEventUsage\x12\x34.strmprivacy.api.usage.v1.GetStreamEventUsageRequest\x1a\x35.strmprivacy.api.usage.v1.GetStreamEventUsageResponse\x12v\n\x0fStoreUsageEvent\x12\x30.strmprivacy.api.usage.v1.StoreUsageEventRequest\x1a\x31.strmprivacy.api.usage.v1.StoreUsageEventResponseB`\n\x1bio.strmprivacy.api.usage.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.usage.v1.usage_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.usage.v1P\001Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usage'
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETSTREAMEVENTUSAGEREQUEST._serialized_start=182
  _GETSTREAMEVENTUSAGEREQUEST._serialized_end=437
  _GETSTREAMEVENTUSAGERESPONSE._serialized_start=440
  _GETSTREAMEVENTUSAGERESPONSE._serialized_end=602
  _STOREUSAGEEVENTREQUEST._serialized_start=605
  _STOREUSAGEEVENTREQUEST._serialized_end=826
  _STOREUSAGEEVENTRESPONSE._serialized_start=828
  _STOREUSAGEEVENTRESPONSE._serialized_end=853
  _USAGESERVICE._serialized_start=856
  _USAGESERVICE._serialized_end=1123
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/credentials/v1/credentials_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/credentials/v1/credentials_v1.proto\x12\x1estrmprivacy.api.credentials.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"d\n\x16ListCredentialsRequest\x12J\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02R\tstreamRef\"e\n\x17ListCredentialsResponse\x12J\n\x0b\x63redentials\x18\x01 \x03(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsR\x0b\x63redentials\"6\n\x17\x44\x65leteCredentialRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\"\x1a\n\x18\x44\x65leteCredentialResponse\"3\n\x14GetCredentialRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\"a\n\x15GetCredentialResponse\x12H\n\ncredential\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsR\ncredential\"`\n\x17\x43reateCredentialRequest\x12\x45\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefR\tstreamRef\"f\n\x18\x43reateCredentialResponse\x12J\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsR\x0b\x63redentials2\xa7\x04\n\x12\x43redentialsService\x12\x82\x01\n\x0fListCredentials\x12\x36.strmprivacy.api.credentials.v1.ListCredentialsRequest\x1a\x37.strmprivacy.api.credentials.v1.ListCredentialsResponse\x12|\n\rGetCredential\x12\x34.strmprivacy.api.credentials.v1.GetCredentialRequest\x1a\x35.strmprivacy.api.credentials.v1.GetCredentialResponse\x12\x85\x01\n\x10\x43reateCredential\x12\x37.strmprivacy.api.credentials.v1.CreateCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.CreateCredentialResponse\x12\x85\x01\n\x10\x44\x65leteCredential\x12\x37.strmprivacy.api.credentials.v1.DeleteCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.DeleteCredentialResponseBr\n!io.strmprivacy.api.credentials.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentialsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.credentials.v1.credentials_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.credentials.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentials'
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._options = None
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._serialized_options = b'\340A\002'
  _LISTCREDENTIALSREQUEST._serialized_start=167
  _LISTCREDENTIALSREQUEST._serialized_end=267
  _LISTCREDENTIALSRESPONSE._serialized_start=269
  _LISTCREDENTIALSRESPONSE._serialized_end=370
  _DELETECREDENTIALREQUEST._serialized_start=372
  _DELETECREDENTIALREQUEST._serialized_end=426
  _DELETECREDENTIALRESPONSE._serialized_start=428
  _DELETECREDENTIALRESPONSE._serialized_end=454
  _GETCREDENTIALREQUEST._serialized_start=456
  _GETCREDENTIALREQUEST._serialized_end=507
  _GETCREDENTIALRESPONSE._serialized_start=509
  _GETCREDENTIALRESPONSE._serialized_end=606
  _CREATECREDENTIALREQUEST._serialized_start=608
  _CREATECREDENTIALREQUEST._serialized_end=704
  _CREATECREDENTIALRESPONSE._serialized_start=706
  _CREATECREDENTIALRESPONSE._serialized_end=808
  _CREDENTIALSSERVICE._serialized_start=811
  _CREDENTIALSSERVICE._serialized_end=1362
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMstrmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto\x12+strmprivacy.api.customer_entity_versions.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\"\x84\x01\n\x1cGetBatchExporterImageRequest\x12\x64\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\"\x97\x01\n\x1dGetBatchExporterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x39\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x05\x18\x01\xe0\x41\x02R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag\"\x1e\n\x1cGetKafkaExporterImageRequest\":\n\x1dGetKafkaExporterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\"\x80\x01\n\x18GetDecrypterImageRequest\x12\x64\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\"\x93\x01\n\x19GetDecrypterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x39\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x05\x18\x01\xe0\x41\x02R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag\"\x85\x01\n\x1dGetBatchJobRunnerImageRequest\x12\x64\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\"\x98\x01\n\x1eGetBatchJobRunnerImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x39\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x05\x18\x01\xe0\x41\x02R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag2\xda\x05\n\x1d\x43ustomerEntityVersionsService\x12\xae\x01\n\x15GetBatchExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageResponse\x12\xae\x01\n\x15GetKafkaExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageResponse\x12\xa2\x01\n\x11GetDecrypterImage\x12\x45.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageRequest\x1a\x46.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageResponse\x12\xb1\x01\n\x16GetBatchJobRunnerImage\x12J.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageRequest\x1aK.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageResponseB\x99\x01\n.io.strmprivacy.api.customer_entity_versions.v1P\x01Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.strmprivacy.api.customer_entity_versions.v1P\001Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versions'
  _GETBATCHEXPORTERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETBATCHEXPORTERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETDECRYPTERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETBATCHJOBRUNNERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_start=212
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_end=344
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_start=347
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_end=498
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_start=500
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_end=530
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_start=532
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_end=590
  _GETDECRYPTERIMAGEREQUEST._serialized_start=593
  _GETDECRYPTERIMAGEREQUEST._serialized_end=721
  _GETDECRYPTERIMAGERESPONSE._serialized_start=724
  _GETDECRYPTERIMAGERESPONSE._serialized_end=871
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_start=874
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_end=1007
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_start=1010
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_end=1162
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_start=1165
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_end=1895
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.consent_levels.v1 import consent_levels_v1_pb2 as strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2


class ConsentLevelMappingsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListConsentLevelMappings = channel.unary_unary(
                '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/ListConsentLevelMappings',
                request_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsResponse.FromString,
                )
        self.GetConsentLevelMapping = channel.unary_unary(
                '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/GetConsentLevelMapping',
                request_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingResponse.FromString,
                )
        self.DeleteConsentLevelMapping = channel.unary_unary(
                '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/DeleteConsentLevelMapping',
                request_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingResponse.FromString,
                )
        self.CreateConsentLevelMapping = channel.unary_unary(
                '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/CreateConsentLevelMapping',
                request_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingResponse.FromString,
                )


class ConsentLevelMappingsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListConsentLevelMappings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConsentLevelMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConsentLevelMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConsentLevelMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConsentLevelMappingsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListConsentLevelMappings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConsentLevelMappings,
                    request_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsResponse.SerializeToString,
            ),
            'GetConsentLevelMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConsentLevelMapping,
                    request_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingResponse.SerializeToString,
            ),
            'DeleteConsentLevelMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConsentLevelMapping,
                    request_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingResponse.SerializeToString,
            ),
            'CreateConsentLevelMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConsentLevelMapping,
                    request_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConsentLevelMappingsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListConsentLevelMappings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/ListConsentLevelMappings',
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsRequest.SerializeToString,
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConsentLevelMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/GetConsentLevelMapping',
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingRequest.SerializeToString,
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConsentLevelMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/DeleteConsentLevelMapping',
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingRequest.SerializeToString,
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConsentLevelMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/CreateConsentLevelMapping',
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingRequest.SerializeToString,
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/handles/v1/handles_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/handles/v1/handles_v1.proto\x12\x1astrmprivacy.api.handles.v1\"I\n\x1eListInstallationHandlesRequest\x12\'\n\x0finstallation_id\x18\x01 \x01(\tR\x0einstallationId\"T\n\x1fListInstallationHandlesResponse\x12\x31\n\x14installation_handles\x18\x01 \x03(\tR\x13installationHandles2\xa5\x01\n\x0eHandlesService\x12\x92\x01\n\x17ListInstallationHandles\x12:.strmprivacy.api.handles.v1.ListInstallationHandlesRequest\x1a;.strmprivacy.api.handles.v1.ListInstallationHandlesResponseBf\n\x1dio.strmprivacy.api.handles.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/handles/v1;handlesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.handles.v1.handles_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.handles.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/handles/v1;handles'
  _LISTINSTALLATIONHANDLESREQUEST._serialized_start=75
  _LISTINSTALLATIONHANDLESREQUEST._serialized_end=148
  _LISTINSTALLATIONHANDLESRESPONSE._serialized_start=150
  _LISTINSTALLATIONHANDLESRESPONSE._serialized_end=234
  _HANDLESSERVICE._serialized_start=237
  _HANDLESSERVICE._serialized_end=402
# @@protoc_insertion_point(module_scope)
